# General todo topics

- Expand test coverage
- Command line tool usage documentation
- API documentation

## Definitions that need to be added

* `CarePlan.activity.goal`
* `CarePlan.relation.*`
* `CarePlanActivityResult.*`
* `CarePlanActivityStatus.blackBoxState` [1]
* `Observation.*`
* `Practitioner.address`
* `Questionnaire.*`
* `RelatedPerson.photo`
* `StorageItem.*`
* `UserMessage.*`

[1] Note the KickAss game does not do implement this following the
specifications

## Missing features

* In a `codeable` support more than one code at a time.
